@@ -29,20 +29,20 @@
 #include <tqslider.h>
 #include <tqlabel.h>
 
-#include <kapplication.h>
-#include <kaction.h>
+#include <tdeapplication.h>
+#include <tdeaction.h>
 #include <kcursor.h>
 #include <kstandarddirs.h>
 #include <kstatusbar.h>
-#include <kfiledialog.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdefiledialog.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <kstringhandler.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kdebug.h>
-#include <kio/job.h>
-#include <ktempfile.h>
-#include <kwin.h>
+#include <tdeio/job.h>
+#include <tdetempfile.h>
+#include <twin.h>
 #include <ktabbar.h>
 
 #include <cmath>
@@ -121,7 +121,7 @@ SQ_GLWidget::SQ_GLWidget(TQWidget *parent, const char *name) : TQGLWidget(parent
     images = 0;
     parts_broken = 0;
 
-    ac = new KActionCollection(this, TQT_TQOBJECT(this), "GLWidget actionCollection");
+    ac = new TDEActionCollection(this, TQT_TQOBJECT(this), "GLWidget actionCollection");
     changed = blocked = decoded = reset_mode = false;
     movetype = -1;
     buffer = new RGBA [512 * 512];
@@ -169,7 +169,7 @@ SQ_GLWidget::SQ_GLWidget(TQWidget *parent, const char *name) : TQGLWidget(parent
     setAcceptDrops(true);
 
     // popup menu with image pages
-    images = new KPopupMenu;
+    images = new TDEPopupMenu;
     images->setCheckable(true);
 
     // create actions
@@ -192,8 +192,8 @@ SQ_GLWidget::SQ_GLWidget(TQWidget *parent, const char *name) : TQGLWidget(parent
     timer_prev = new TQTimer(this);
     timer_next = new TQTimer(this);
 
-    Q_CHECK_PTR(timer_prev);
-    Q_CHECK_PTR(timer_next);
+    TQ_CHECK_PTR(timer_prev);
+    TQ_CHECK_PTR(timer_next);
 
     connect(timer_prev, TQT_SIGNAL(timeout()), SQ_WidgetStack::instance(), TQT_SLOT(emitPreviousSelected()));
     connect(timer_next, TQT_SIGNAL(timeout()), SQ_WidgetStack::instance(), TQT_SLOT(emitNextSelected()));
@@ -201,7 +201,7 @@ SQ_GLWidget::SQ_GLWidget(TQWidget *parent, const char *name) : TQGLWidget(parent
 
     timer_anim = new TQTimer(this);
 
-    Q_CHECK_PTR(timer_anim);
+    TQ_CHECK_PTR(timer_anim);
 
     connect(timer_anim, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotAnimateNext()));
 
@@ -572,7 +572,7 @@ void SQ_GLWidget::mousePressEvent(TQMouseEvent *e)
         SQ_Config::instance()->setGroup("GL view");
         int dc = SQ_Config::instance()->readNumEntry("double_click", 0);
 
-        if(dc && clickTime.isValid() && clickTime.msecsTo(t) <= KApplication::doubleClickInterval())
+        if(dc && clickTime.isValid() && clickTime.msecsTo(t) <= TDEApplication::doubleClickInterval())
         {
             if(dc == 1)
                 KSquirrel::app()->closeGLWidget();
@@ -1253,7 +1253,7 @@ void SQ_GLWidget::startDecoding(const TQString &file)
 #endif
 
     if(m_expected.isEmpty())
-        KApplication::eventLoop()->processEvents(TQEventLoop::ExcludeUserInput | TQEventLoop::ExcludeSocketNotifiers);
+        TDEApplication::eventLoop()->processEvents(TQEventLoop::ExcludeUserInput | TQEventLoop::ExcludeSocketNotifiers);
 
     decode();
 }
@@ -1475,7 +1475,7 @@ void SQ_GLWidget::decode()
 
         // absolute evil, but should do...
         if(notexpected)
-            KApplication::eventLoop()->processEvents(TQEventLoop::ExcludeUserInput | TQEventLoop::ExcludeSocketNotifiers);
+            TDEApplication::eventLoop()->processEvents(TQEventLoop::ExcludeUserInput | TQEventLoop::ExcludeSocketNotifiers);
 
         i = tab->codeK->read_next();
 
@@ -1515,7 +1515,7 @@ void SQ_GLWidget::decode()
             {
                 KMessageBox::error(this,
                             i18n("Memory allocation failed for %1 of memory")
-                            .arg(KIO::convertSize(pp.realw * pp.realh * sizeof(RGBA))));
+                            .arg(TDEIO::convertSize(pp.realw * pp.realh * sizeof(RGBA))));
 
                 decodeFailedOn0(SQE_R_NOMEMORY);
                 return;
@@ -1633,9 +1633,9 @@ void SQ_GLWidget::decode()
     tab->elapsed = started.elapsed();
 
 #ifndef KSQUIRREL_PART
-    SQ_GLView::window()->sbarWidget("SBLoaded")->setText(KGlobal::locale()->formatLong(tab->elapsed) + i18n(" ms."));
+    SQ_GLView::window()->sbarWidget("SBLoaded")->setText(TDEGlobal::locale()->formatLong(tab->elapsed) + i18n(" ms."));
 #else
-    t_glv.sbarWidget("SBLoaded")->setText(KGlobal::locale()->formatLong(tab->elapsed) + i18n(" ms."));
+    t_glv.sbarWidget("SBLoaded")->setText(TDEGlobal::locale()->formatLong(tab->elapsed) + i18n(" ms."));
 #endif
 
     images->setItemChecked(first_id, true);
@@ -1997,7 +1997,7 @@ void SQ_GLWidget::setDownloadPercents(int p)
         percentsLabel->hide();
     else
     {
-        percentsLabel->setText(i18n("Downloading...") + ' ' + KIO::convertSize(p));
+        percentsLabel->setText(i18n("Downloading...") + ' ' + TDEIO::convertSize(p));
         percentsLabel->adjustSize();
         percentsLabel->show();
     }
